"""
================================================================================
pyDOE: Design of Experiments for Python
================================================================================

Author: Abraham Lee
Copyright: 2013

"""
# from __future__ import absolute_import

__author__ = 'Abraham Lee'
__version__ = '0.3.4'

from pyDOE.doe_box_behnken import *
from pyDOE.doe_composite import *
from pyDOE.doe_factorial import *
from pyDOE.doe_lhs import *
from pyDOE.doe_fold import *
from pyDOE.doe_plackett_burman import *
    
